pub struct BrokerConfiguration {
pub object_store: Arc<dyn ObjectStore>,
pub batch_coordinator: Arc<dyn BatchCoordinator>,
pub flush_interval_in_ms: u64,
pub segment_size_in_bytes: u64,
}Expand description
Configuration for the broker containing required dependencies.
Fields
object_store: Arc<dyn ObjectStore>The object store implementation used for persisting message batches
batch_coordinator: Arc<dyn BatchCoordinator>The batch coordinator responsible for assigning offsets to batches
flush_interval_in_ms: u64segment_size_in_bytes: u64Trait Implementations